sap.ui.define([
	"sap/ui/core/mvc/Controller",
	"sap/ui/core/UIComponent",
	"sap/ui/core/routing/History",
	"sap/ui/model/json/JSONModel"
], function (Controller, UIComponent, History, JSONModel) {
	"use strict";
	return Controller.extend("whitepaper-id.com.WhintMessageStoreViewer.controller.Attachment", {
		/**
		 * Called when a controller is instantiated and its View controls (if available) are already created.
		 * Can be used to modify the View before it is displayed, to bind event handlers and do other one-time initialization.
		 * @memberOf whitepaper-id.com.WhintMessageStoreViewer.view.Attachment
		 */
		onInit: function () {
			var oRouter = sap.ui.core.UIComponent.getRouterFor(this);
			oRouter.getRoute("Attachment").attachMatched(this._onRouteMatched, this);
		},
		_onRouteMatched: function (oEvent) {
			var oArgs, oView;
			oArgs = oEvent.getParameter("arguments");
			oView = this.getView();
			oView.bindElement({
				path: "/MessageStoreEntries('" + oArgs.entryId + "')/Attachments",
				events: {
					dataRequested: function () {
						oView.setBusy(true);
					},
					dataReceived: function () {
						oView.setBusy(false);
					}
				}
			});
			/* Call to get the entry attachments */
			var data = null;
			var userResults = new JSONModel({
				"data": {}
			});
			var self = this;
			self.getView().setModel(userResults, "attachments");
			var xhr = new XMLHttpRequest();
			xhr.withCredentials = false;
			xhr.addEventListener("readystatechange", function () {
				if (this.readyState === this.DONE) {
					var jsonResults = JSON.parse(this.response).d.results;
					self.getView().getModel("attachments").setProperty("/data", jsonResults);
				}
			});
			//setting request method
			xhr.open("GET", "/destinations/MessageStoreAPI/v1/MessageStoreEntries('" + oArgs.entryId + "')/Attachments");
			//adding request headers
			xhr.setRequestHeader("Content-Type", "application/json");
			xhr.setRequestHeader("Accept", "application/json");
			//API Key for API Sandbox
			xhr.setRequestHeader("APIKey", "20olT3xIOAEcCk2oSi40LFWkQMACYGYe");
			//Available Security Schemes for productive API Endpoints
			//Basic Authentication
			//Basic Auth : provide username:password in Base64 encoded in Authorization header
			xhr.setRequestHeader("Authorization", "Basic <Base64 encoded value>");
			//sending request
			xhr.send(data);
		},
		handleNavButtonPress: function () {
			var oHistory = History.getInstance();
			var sPreviousHash = oHistory.getPreviousHash();
			if (sPreviousHash !== undefined) {
				window.history.go(-1);
			} else {
				var oRouter = UIComponent.getRouterFor(this);
				oRouter.navTo("overview", {}, true);
			}
		},
		handlePressPayload: function (oEvent, data) {
		//	alert("Navigating to attachment file of entry ID: " + data);
			//open in new window
			window.open("/destinations/MessageStoreAPI/v1/MessageStoreEntryAttachments('" + data + "')/$value");
		},

		goToDetail: function (oEvent, data) {
			 	var oRouter = sap.ui.core.UIComponent.getRouterFor(this);
				oRouter.navTo("AttachProp", {
				entryId: data
			});
			}
			/**
			 * Similar to onAfterRendering, but this hook is invoked before the controller's View is re-rendered
			 * (NOT before the first rendering! onInit() is used for that one!).
			 * @memberOf whitepaper-id.com.WhintMessageStoreViewer.view.Attachment
			 */
			//	onBeforeRendering: function() {
			//
			//	},
			/**
			 * Called when the View has been rendered (so its HTML is part of the document). Post-rendering manipulations of the HTML could be done here.
			 * This hook is the same one that SAPUI5 controls get after being rendered.
			 * @memberOf whitepaper-id.com.WhintMessageStoreViewer.view.Attachment
			 */
			//	onAfterRendering: function() {
			//
			//	},
			/**
			 * Called when the Controller is destroyed. Use this one to free resources and finalize activities.
			 * @memberOf whitepaper-id.com.WhintMessageStoreViewer.view.Attachment
			 */
			//	onExit: function() {
			//
			//	}

		/**
		 *@memberOf whitepaper-id.com.WhintMessageStoreViewer.controller.Attachment
		 */

	});
});