sap.ui.define([
	"sap/ui/core/mvc/Controller",
	"sap/ui/core/routing/History",
	"sap/ui/core/UIComponent",
	"sap/ui/model/json/JSONModel"
	], function (Controller, History, UIComponent, JSONModel) {
	"use strict";
	return Controller.extend("whitepaper-id.com.WhintMessageStoreViewer.controller.Detail", {
		/**
		 * Called when a controller is instantiated and its View controls (if available) are already created.
		 * Can be used to modify the View before it is displayed, to bind event handlers and do other one-time initialization.
		 * @memberOf whitepaper-id.com.WhintMessageStoreViewer.view.Detail
		 */
		onInit: function () {

			var oRouter = sap.ui.core.UIComponent.getRouterFor(this);
			oRouter.getRoute("Detail").attachMatched(this._onRouteMatched, this);

		},

		_onRouteMatched: function (oEvent) {
			var oArgs, oView;
			oArgs = oEvent.getParameter("arguments");
			oView = this.getView();
			oView.bindElement({
				path: "/MessageStoreEntries('" + oArgs.entryId + "')/Properties",
				events: {
					dataRequested: function () {
						oView.setBusy(true);
					},
					dataReceived: function () {
						oView.setBusy(false);
					}
				}
			});
			
		/* Call to get the properties of store entries */

			var data = null;
			var userResults = new JSONModel({
				"data": {}
			});
			var self = this;
			self.getView().setModel(userResults, "props");
			var xhr = new XMLHttpRequest();
			xhr.withCredentials = false;
			xhr.addEventListener("readystatechange", function () {
				if (this.readyState === this.DONE) {
					var jsonResults = JSON.parse(this.response).d.results;
					self.getView().getModel("props").setProperty("/data", jsonResults);
				}
			});
			//setting request method
			xhr.open("GET", "/destinations/MessageStoreAPI/v1/MessageStoreEntries('" + oArgs.entryId + "')/Properties");
			//adding request headers
			xhr.setRequestHeader("Content-Type", "application/json");
			xhr.setRequestHeader("Accept", "application/json");
			//API Key for API Sandbox
			xhr.setRequestHeader("APIKey", "20olT3xIOAEcCk2oSi40LFWkQMACYGYe");
			//Available Security Schemes for productive API Endpoints
			//Basic Authentication
			//Basic Auth : provide username:password in Base64 encoded in Authorization header
			xhr.setRequestHeader("Authorization", "Basic <Base64 encoded value>");
			//sending request
			xhr.send(data);

		},
		
		handleNavButtonPress: function () {
			var oHistory = History.getInstance();
			var sPreviousHash = oHistory.getPreviousHash();

			if (sPreviousHash !== undefined) {
				window.history.go(-1);
			} else {
				var oRouter = UIComponent.getRouterFor(this);
				oRouter.navTo("overview", {}, true);
			}
		}
	 
	});
});